@@ -33,7 +33,21 @@ class KensuBigQuerySupport(ExtractorSupport):  # should extends some KensuSuppor
     # return list of FieldDef
     def extract_schema_fields(self, df):
         if isinstance(df, google.cloud.bigquery.table.Table) or isinstance(df, google.cloud.bigquery.table.RowIterator):
-            return [FieldDef(name=str(k.name), field_type=k.field_type, nullable=k.is_nullable) for k in df.schema]
+            schema_field = []
+            def convert_fields(fields,heritage=[]):
+                for k in fields:
+                    if k.fields != ():
+                        heritage.append(k.name)
+                        convert_fields(k.fields,heritage)
+                        heritage=[]
+                    else:
+                        if heritage !=[]:
+                            prefix = ".".join(heritage)+'.'
+                        else:
+                            prefix=''
+                        schema_field.append(FieldDef(name=prefix+str(k.name), field_type=k.field_type, nullable=k.is_nullable))
+            convert_fields(df.schema)
+            return schema_field
 
 
     def extract_location(self, df, location):
