@@ -1,5 +1,7 @@
 import logging
 
+from kensu.client.models import Schema
+
 
 class KensuDatasourceAndSchema:
     def __init__(self,
@@ -86,7 +88,12 @@ class GenericComputedInMemDs:
         for input_ds in self.inputs:
             extract_ksu_ds_schema(ksu, input_ds, report=True, register_orig_data=True)
         # report output (if needed)
-        result_ds, result_schema = extract_ksu_ds_schema(ksu, df_result, report=report_output, register_orig_data=register_output_orig_data)
+        if isinstance(df_result,Schema):
+            result_ds = None
+            result_schema = df_result._report()
+            ksu.real_schema_df[result_schema.to_guid()] = df_result
+        else:
+            result_ds, result_schema = extract_ksu_ds_schema(ksu, df_result, report=report_output, register_orig_data=register_output_orig_data)
         # register the lineage
         for dep in self.lineage:
             input_ds = dep.input_ds
